@@ -467,8 +467,7 @@ let main () =
       let transitions =
         List.fold_left
           (fun transitions -> function
-            | Some t -> t :: transitions
-            | None -> transitions)
+            | Some t -> t :: transitions | None -> transitions)
           [] transitions
       in
       (* Read ben.cache *)
@@ -505,8 +504,7 @@ let main () =
       let results =
         List.fold_left
           (fun results -> function
-            | n, p, Some d -> (n, p, d) :: results
-            | _ -> results)
+            | n, p, Some d -> (n, p, d) :: results | _ -> results)
           [] results
       in
       (* Compute collisions *)
@@ -528,7 +526,9 @@ let main () =
       (* Clean up the HTML directory from old files *)
       let () = clean_up profiles in
       (* Generate the index page *)
-      match !tconfig with None -> tracker template profiles | Some _ -> ()
+      match !tconfig with
+      | None -> tracker template profiles
+      | Some _ -> ()
     with exn ->
       Error.error_exn "General error" exn;
       exit 42
